<?php
// wcf imports
require_once(WCF_DIR.'lib/util/pip/AbstractXMLPIP.class.php');

/**
 * Creates a languages XML-PIP
 *
 * @package	com.woltlab.community.wcf.util.package
 * @author	Alexander Ebert
 * @copyright	2010 WoltLab Community
 * @license	GNU Lesser Public License <http://www.gnu.org/licenses/lgpl.html>
 * @subpackage	lib.util.pip
 */
class LanguagesXMLPIP extends AbstractXMLPIP {
	/**
	 * Returns a valid language xml string
	 *
	 * Usage:
	 * LanguageXMLPIP::create(array(
	 * 	'en' => array(
	 * 		'category' => array(
	 * 			'item' => 'value'
	 * 		)
	 * 	)
	 * ));
	 *
	 * @see	AbstractXMLPIP::create()
	 */
	public static function create ($data, $appendParentCategory = false) {
		// xml header
		$xml = '<?xml version="1.0" encoding="UTF-8"?>';

		foreach ($data as $languageCode => $languageData) {
			self::createLanguageXML($languageCode, $languageData, $xml, $appendParentCategory);
		}

		return $xml;
	}

	/**
	 * @param	string		$languageCode	ISO 639-1 country code
	 * @param	array<array>	$data		Language categories and items
	 * @param	string		$xml		Reference to current xml string
	 * @param	boolean		$appendCategory	Defaults to true. Prefixes item names with category name
	 * @return	string		Language XML string
	 * @see		LanguageXMLPIP::create()
	 */
	public static function createLanguageXML ($languageCode, $data, &$xml, $appendParentCategory) {
		$xml .= "\n".'<language languagecode="'.$languageCode.'" xmlns="http://www.woltlab.com" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://www.woltlab.com/XSD/languages.xsd">';

		// append all categories
		foreach ($data as $category => $items) {
			$xml .= "\n\t<category name=\"".$category."\">";

			// append all items within one category
			foreach ($items as $itemName => $itemValue) {
				// prefix with category if applicable
				if ($appendParentCategory) $itemName = $category.'.'.$itemName;

    				$xml .= "\n\t\t<item name=\"".$itemName."\"><![CDATA[".$itemValue."]]></item>";
			}

			$xml .= "\n\t</category>";
		}

		// xml footer
		$xml .= "\n</language>";
	}
}
?>